Strategy
----------

A strategy helps a minimizer in some situations - such as when encountering NaNs - and hooks
into the loss evaluation. They can be used to create a


Strategies
===========

.. autosummary::
    :toctree: _generated/strategy

    zfit.minimize.PushbackStrategy
    zfit.minimize.DefaultStrategy
    zfit.minimize.DefaultToyStrategy
